Module zkstd::common

source ·
export necessary traits for crypto Substrate compatible.

Re-exports

Modules

  • A contiguous growable array type with heap-allocated contents, written Vec<T>.

Macros

  • Creates a Vec containing the arguments.

Structs

  • Configuration for formatting.
  • A contiguous growable array type, written as Vec<T>, short for ‘vector’.

Enums

  • An Ordering is the result of a comparison between two values.

Traits

  • The addition operator +.
  • The addition assignment operator +=.
  • The bitwise AND operator &.
  • The bitwise XOR operator ^.
  • ? formatting.
  • Trait that allows zero-copy read of value-references from slices in LE format.
  • Format trait for an empty format, {}.
  • The division operator /.
  • The division assignment operator /=.
  • Trait that allows zero-copy write of value-references to slices in LE format.
  • x formatting.
  • The multiplication operator *.
  • The multiplication assignment operator *=.
  • The unary negation operator -.
  • The core of a random number generator.
  • The subtraction operator -.
  • The subtraction assignment operator -=.

Type Aliases

  • The type returned by formatter methods.

Derive Macros

  • Derive macro generating an impl of the trait Debug.
  • Derive parity_scale_codec::Decode and for struct and enum.
  • Derive parity_scale_codec::Encode and parity_scale_codec::EncodeLike for struct and enum.